@@ -37,6 +37,7 @@ View contains three part:
 #include "../jammo-game-level.h"
 #include "../jammo-game-level-view.h"
 
+#include "../../configure.h"
 /*
 Sequencer and sequencer-track-view-area are defined in json.
 
@@ -57,69 +58,53 @@ JammoMetronomeTrack* static_metronome_track;
 
 
 gboolean sequencer_change_to_loop_view(TangleActor *actor, gpointer data) {
-	printf("changing view to loop \n");
+	cem_add_to_log("changing view to loop",J_LOG_INFO);
 	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-view-container");
+	if (scrolling_view==NULL){
+		cem_add_to_log("no actor 'fullsequencer-view-container'",J_LOG_ERROR);
+		return TRUE;
+	}
 	ClutterAction* action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_CIRC, 400, "offset-y", 0.0, NULL);
 	return TRUE;
 }
 
 gboolean sequencer_change_to_sequencer_view(TangleActor *actor, gpointer data) {
-	printf("changing view to sequencer \n");
+	cem_add_to_log("changing view to sequencer",J_LOG_INFO);
 	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-view-container");
+	if (scrolling_view==NULL){
+		cem_add_to_log("no actor 'fullsequencer-view-container'",J_LOG_ERROR);
+		return TRUE;
+	}
 	ClutterAction* action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_CIRC, 400, "offset-y", 480.0, NULL);
 	return TRUE;
 }
 
 gboolean sequencer_change_to_bottom_view (TangleActor *actor, gpointer data) {
-	printf("changing view to bottom \n");
+	cem_add_to_log("changing view to general menu",J_LOG_INFO);
 	ClutterActor* scrolling_view = jammo_get_actor_by_id("fullsequencer-view-container");
+	if (scrolling_view==NULL){
+		cem_add_to_log("no actor 'fullsequencer-view-container'",J_LOG_ERROR);
+		return TRUE;
+	}
 	ClutterAction* action = tangle_actor_get_action_by_type(scrolling_view,TANGLE_TYPE_SCROLL_ACTION);
 	tangle_object_animate(G_OBJECT(action), CLUTTER_EASE_IN_CIRC, 400, "offset-y", 960.0, NULL);
 	return TRUE;
 }
 
-
-
-//We want load saved composition only first time
-static gboolean first_time = TRUE;
-
-
-/* JSON callback when sequencer-view is showed*/
-void start_sequencer_full_sequencer (TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
-	if (first_time){
-		gchar* filename = tangle_lookup_filename("seq.json"); //This is default
-		start_sequencer(filename);
-		g_free(filename);
-	}
-	first_time=FALSE;
-
-}
-
-/*
-This actor is visible when starting jammo_get_actor_by_id("fullsequencer-view");
-*/
-void start_sequencer(gpointer filename)
+static ClutterActor* current_levelview =NULL;
+void start_fullsequencer_gui(ClutterActor* levelview)
 {
-	printf("Starting sequencer GUI\n");
+	current_levelview=levelview;
+	cem_add_to_log("Sequencer GUI starts",J_LOG_INFO);
+	clutter_actor_show(current_levelview);
 	ClutterAction* action = tangle_actor_get_action_by_type(jammo_get_actor_by_id("fullsequencer-view-container"), TANGLE_TYPE_SCROLL_ACTION);
 	g_signal_connect_swapped(action, "clamp-offset-y", G_CALLBACK(tangle_widget_clamp_child_boundaries), jammo_get_actor_by_id("fullsequencer-view-container"));
 
 	static_sequencer = JAMMO_SEQUENCER(jammo_get_object_by_id("fullsequencer-the-sequencer"));
 	static_metronome_track = NULL;
 
-	//inputFilename is global! (from sequencer.h)
-	if (filename == NULL)
-		inputFilename = NULL;
-	else {
-		inputFilename = malloc(strlen((gchar*) filename) + 1);
-		memcpy(inputFilename, (gchar*) filename, strlen((gchar*) filename) + 1);
-		printf("The filename is '%s'\n",inputFilename);
-	}
-
-
-
 	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 
 
@@ -136,32 +121,16 @@ void start_sequencer(gpointer filename)
 	sequencer_change_to_sequencer_view(NULL,NULL); //Start to middle view.
 }
 
-/*
-void leave_sequencer()
-{
-	clutter_actor_hide(CLUTTER_ACTOR(sequencer_view));
-
-	start_startmenu();
+void return_to_fullsequencer_gui(){
+clutter_actor_show(current_levelview);
 }
-*/
-
-
-
-
-
 
 /*
  * CallBack for JSON
  */
-void fullsequencer_general_arrow_clicked (TangleButton *tanglebutton, gpointer user_data){
-printf("up\n");
-sequencer_change_to_sequencer_view(NULL,NULL);
-}
-
 
 void fullsequencer_general_tempo_clicked(TangleButton *tanglebutton, gpointer user_data) {
 	const gchar* name=clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
-	printf("tempo clicked '%s'\n",name);
 	if (name==NULL)
 		return;
 
@@ -172,14 +141,17 @@ void fullsequencer_general_tempo_clicked(TangleButton *tanglebutton, gpointer us
 			new_tempo=110;
 	else if (strncmp(name,"slow",4)==0)
 			new_tempo=90;
-	printf("new tempo:%d\n",new_tempo);
+
+	gchar* message = g_strdup_printf("tempo '%s'='%d' clicked",name,new_tempo);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
+
 	jammo_sequencer_set_tempo(static_sequencer, new_tempo);
 }
 
 
 void fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer user_data) {
 	const gchar* name=clutter_actor_get_name(CLUTTER_ACTOR(tanglebutton));
-	printf("pitch clicked '%s'\n",name);
 	if (name==NULL)
 		return;
 
@@ -190,18 +162,51 @@ void fullsequencer_general_pitch_clicked(TangleButton *tanglebutton, gpointer us
 			new_pitch = "D";
 	else if (strncmp(name,"low",3)==0)
 			new_pitch = "A";
-	printf("new pitch:'%s'\n",new_pitch);
+
+	gchar* message = g_strdup_printf("pitch '%s'='%s' clicked",name,new_pitch);
+	cem_add_to_log(message,J_LOG_USER_ACTION);
+	g_free(message);
 
 	jammo_sequencer_set_pitch(static_sequencer, new_pitch);
 }
 
 
+static void on_rendering_stopped(JammoSequencer* sequencer, gpointer none) {
+	cem_add_to_log("Rendering ready",J_LOG_INFO);
+	g_signal_handlers_disconnect_by_func(sequencer, on_rendering_stopped, NULL);
+	if (!(jammo_sequencer_set_output_filename(sequencer, NULL))) {
+		cem_add_to_log("Problem going back to playback-mode after render",J_LOG_ERROR);
+	}
+
+}
+
 void sequencer_render_button_pressed (TangleButton* tanglebutton, gpointer none){
-	cem_add_to_log("sequencer_render_button_pressed",LOG_USER_ACTION);
+	cem_add_to_log("Render-button pressed",J_LOG_USER_ACTION);
+
+	char timestamp [80];
+	cem_get_time(timestamp);
+
+	gchar* jammo_directory=configure_get_jammo_directory();
+	gchar* outputFilename = g_strdup_printf("%s/%s.ogg",jammo_directory,timestamp);
+	g_free(jammo_directory);
+
+	gchar* message = g_strdup_printf("Rendering file named '%s'",outputFilename);
+	cem_add_to_log(message,J_LOG_INFO);
+	g_free(message);
+
+	if (jammo_sequencer_set_output_filename(static_sequencer, outputFilename)) {
+		g_signal_connect(static_sequencer, "stopped", G_CALLBACK(on_rendering_stopped), NULL);
+		jammo_sequencer_play(static_sequencer);
+	}
+	else
+		cem_add_to_log("Can't render audiofile",J_LOG_ERROR);
+
+	g_free(outputFilename);
 }
 
 void fullsequencer_metronome_clicked (TangleButton* tanglebutton, gpointer none){
-	printf("fullsequencer: Metronome pressed\n");
+	cem_add_to_log("Metronome pressed",J_LOG_USER_ACTION);
+
 	if (static_metronome_track==NULL) {
 		static_metronome_track = jammo_metronome_track_new();
 		jammo_sequencer_add_track(static_sequencer, JAMMO_TRACK(static_metronome_track));
